@@ -29,12 +29,12 @@
 # The fact that you are presently reading this means that you have had
 # knowledge of the CeCILL license and that you accept its terms.
 
-from typing import Callable, Iterable
+from typing import Iterable
 
 import numpy as nmpy
 
-from skl_graph.task.plot.base import axes_t
-from skl_graph.type.edge import array_t, edge_t
+from skl_graph.task.plot.base import axes_t, y_transform_h
+from skl_graph.type.edge import edge_t
 from skl_graph.type.plot import (
     direction_style_t,
     edge_styles_h,
@@ -44,12 +44,18 @@ from skl_graph.type.plot import (
 
 
 _SUBSAMPLING_FACTOR = 0.75
+_LABEL_BBOX_STYLE = {
+    "facecolor": "w",
+    "linestyle": "",
+    "alpha": 0.5,
+    "boxstyle": "square,pad=0",
+}
 
 
 def Plot(
     edges: Iterable[tuple[str, str, edge_t]],
-    TransformedY: Callable[[array_t], array_t],
-    TransformedYForVector: Callable[[array_t], array_t],
+    TransformedY: y_transform_h,
+    TransformedYForVector: y_transform_h,
     axes: axes_t,
     edge_styles: edge_styles_h,
     direction_style: direction_style_t,
@@ -118,7 +124,7 @@ def Plot(
         if label_style.show:
             middle_idx = sites[0].size // 2
             position = tuple(_crd[middle_idx] for _crd in sites)
-            PlotEdgeLabel(
+            label = PlotEdgeLabel(
                 *position,
                 details.uid,
                 fontsize=label_style.size,
@@ -126,3 +132,4 @@ def Plot(
                 horizontalalignment="center",
                 verticalalignment="center",
             )
+            label.set_bbox(_LABEL_BBOX_STYLE)
