@@ -32,7 +32,8 @@
 from __future__ import annotations
 
 import dataclasses as dtcl
-from typing import Any, Callable
+from types import MethodType
+from typing import Any
 from typing import NamedTuple as named_tuple_t
 from typing import Sequence
 
@@ -142,7 +143,7 @@ class edge_t(raw_edge_t):
         """"""
         return self._Direction(self.FinalDirection)
 
-    def _Direction(self, caller: Callable, /) -> array_t:
+    def _Direction(self, caller: MethodType, /) -> array_t:
         """"""
         cache_entry = caller.__name__
         if cache_entry not in self._cache:
